import type { SecurityVariable, ServerVariable } from '..';
export declare type TargetId = keyof typeof targets;
export declare type SnippetType = 'webhooks' | 'server';
export declare type ClientId = string;
export interface ClientInfo {
    key: ClientId;
    title: string;
    link: string;
    description: string;
}
export interface ClientRanges {
    security?: Record<string, {
        line: number;
    }>;
    server?: Record<string, {
        line: number;
    }>;
}
export declare type Converter = (params: {
    secret?: string;
    security: SecurityVariable[];
    server: ServerVariable[];
}) => {
    ranges: ClientRanges;
    snippet: string;
};
export declare type Client = {
    info: ClientInfo;
    convert: Converter;
};
export declare type Extension = `.${string}` | null;
export interface TargetInfo {
    key: TargetId;
    title: string;
    extname: Extension;
    default: string;
    cli?: string;
}
export interface Target {
    info: TargetInfo;
    services: {
        webhooks: Record<ClientId, Client>;
        server: Record<ClientId, Client>;
    };
}
export declare const targets: {
    csharp: Target;
    node: Target;
    php: Target;
    python: Target;
};
